@@ -6,8 +6,8 @@
 # This is due to the fact that coverage will not include the first loaded spec/test file.
 # To get predictable coverage results, we need to know which one that is...
 #
-Transform "bundle exec rspec spec" do |t|
+Transform "bundle exec rspec spec" do |_|
   files = nil # Avoid shadowing
-  in_current_dir { files = Dir['spec/**/*_spec.rb'] }
+  in_current_dir { files = Dir["spec/**/*_spec.rb"] }
   "bundle exec rspec #{files.sort.join(' ')}"
 end
