@@ -4,7 +4,7 @@ class FakedProject
   end
 end
 
-Dir[File.join(File.dirname(__FILE__), 'faked_project/*.rb')].each do |file|
+Dir[File.join(File.dirname(__FILE__), "faked_project/*.rb")].each do |file|
   require file # Require all source files in project dynamically so we can inject some stuff depending on test situation
 end
 
