@@ -1,23 +1,16 @@
-require 'bundler/setup'
-require 'simplecov'
-require 'test/unit'
-require 'shoulda'
+require "bundler/setup"
+require "simplecov"
+require "minitest/autorun"
+require "shoulda"
 
-SimpleCov.coverage_dir('tmp/coverage')
-
-class Test::Unit::TestCase
-  def source_fixture(filename)
-    File.expand_path(File.join(File.dirname(__FILE__), 'fixtures', filename))
-  end
-
-  # Keep 1.8-rubies from complaining about missing tests in each file that covers only 1.9 functionality
-  def default_test
-  end
+SimpleCov.coverage_dir("tmp/coverage")
 
+def source_fixture(filename)
+  File.expand_path(File.join(File.dirname(__FILE__), "fixtures", filename))
 end
 
-require 'shoulda_macros'
-Test::Unit::TestCase.send :extend, ShouldaMacros
+require "shoulda_macros"
+Minitest::Test.send :extend, ShouldaMacros
 
 # Taken from http://stackoverflow.com/questions/4459330/how-do-i-temporarily-redirect-stderr-in-ruby
 require "stringio"
